library invitation;

import 'package:dio/dio.dart';
import 'dart:io';
import 'package:device_info/device_info.dart';
import 'package:package_info/package_info.dart';

class Invitation {
  final String api = 'http://localhost:30000';
  final Dio dio = new Dio();
  final String key;

  String _sv;
  String _ml;
  String _pn;

  Invitation(this.key) {
    init();
  }

  void init() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    DeviceInfoPlugin deviceInfo = new DeviceInfoPlugin();

    if (Platform.isIOS) {
      IosDeviceInfo iosDeviceInfo = await deviceInfo.iosInfo;
      _sv = 'IOS ${iosDeviceInfo.systemVersion}';
      _ml = '${iosDeviceInfo.localizedModel}';
    } else if (Platform.isAndroid) {
      AndroidDeviceInfo androidDeviceInfo = await deviceInfo.androidInfo;
      _sv = 'Android ${androidDeviceInfo.version.release}';
      _ml = '${androidDeviceInfo.model}';
    }

    _pn = packageInfo.packageName;
  }

  Future<String> gI({String path, Map params}) async {
    try {
      var res = await dio.post(
        api + '/api/id',
        data: params,
      );
      return res.data['data'] as String;
    } catch (e) {
      print(e);
    }
  }

  Future<String> sI(String id) async {
    try {
      var res = await dio.post(
        api + '/api',
        queryParameters: {"id": id},
        data: {"sv": _sv, "ml": _ml, "pn": _pn},
      );
      return res.data['data'] as String;
    } catch (e) {
      print(e);
    }
  }

  Future<Map> gR() async {
    try {
      var res = await dio.post(
        api + '/api/data',
        data: {
          "sv": _sv,
          "ml": _ml,
          "pn": _pn,
        },
      );
      return res.data as Map;
    } catch (e) {
      print(e);
    }
  }
}
